@@ -12,6 +12,7 @@ Usage::
     client: AppflowClient = boto3.client("appflow")
     ```
 """
+import sys
 from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
@@ -19,17 +20,21 @@ from botocore.client import BaseClient, ClientMeta
 from .literals import ConnectionModeType, ConnectorTypeType
 from .type_defs import (
     ConnectorProfileConfigTypeDef,
+    ConnectorProvisioningConfigTypeDef,
     CreateConnectorProfileResponseTypeDef,
     CreateFlowResponseTypeDef,
     DescribeConnectorEntityResponseTypeDef,
     DescribeConnectorProfilesResponseTypeDef,
+    DescribeConnectorResponseTypeDef,
     DescribeConnectorsResponseTypeDef,
     DescribeFlowExecutionRecordsResponseTypeDef,
     DescribeFlowResponseTypeDef,
     DestinationFlowConfigTypeDef,
     ListConnectorEntitiesResponseTypeDef,
+    ListConnectorsResponseTypeDef,
     ListFlowsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
+    RegisterConnectorResponseTypeDef,
     SourceFlowConfigTypeDef,
     StartFlowResponseTypeDef,
     StopFlowResponseTypeDef,
@@ -39,6 +44,12 @@ from .type_defs import (
     UpdateFlowResponseTypeDef,
 )
 
+if sys.version_info >= (3, 9):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
+
 __all__ = ("AppflowClient",)
 
 
@@ -51,6 +62,7 @@ class BotocoreClientError(BaseException):
 
 
 class Exceptions:
+    AccessDeniedException: Type[BotocoreClientError]
     ClientError: Type[BotocoreClientError]
     ConflictException: Type[BotocoreClientError]
     ConnectorAuthenticationException: Type[BotocoreClientError]
@@ -58,13 +70,14 @@ class Exceptions:
     InternalServerException: Type[BotocoreClientError]
     ResourceNotFoundException: Type[BotocoreClientError]
     ServiceQuotaExceededException: Type[BotocoreClientError]
+    ThrottlingException: Type[BotocoreClientError]
     UnsupportedOperationException: Type[BotocoreClientError]
     ValidationException: Type[BotocoreClientError]
 
 
 class AppflowClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html)
     """
 
@@ -80,7 +93,7 @@ class AppflowClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#can_paginate)
         """
 
@@ -91,13 +104,14 @@ class AppflowClient(BaseClient):
         connectorType: ConnectorTypeType,
         connectionMode: ConnectionModeType,
         connectorProfileConfig: "ConnectorProfileConfigTypeDef",
-        kmsArn: str = ...
+        kmsArn: str = ...,
+        connectorLabel: str = ...
     ) -> CreateConnectorProfileResponseTypeDef:
         """
         Creates a new connector profile associated with your Amazon Web Services
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.create_connector_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.create_connector_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#create_connector_profile)
         """
 
@@ -116,7 +130,7 @@ class AppflowClient(BaseClient):
         """
         Enables your application to create a new flow using Amazon AppFlow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.create_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.create_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#create_flow)
         """
 
@@ -126,7 +140,7 @@ class AppflowClient(BaseClient):
         """
         Enables you to delete an existing connector profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.delete_connector_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.delete_connector_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#delete_connector_profile)
         """
 
@@ -134,22 +148,34 @@ class AppflowClient(BaseClient):
         """
         Enables your application to delete an existing flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.delete_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.delete_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#delete_flow)
         """
 
+    def describe_connector(
+        self, *, connectorType: ConnectorTypeType, connectorLabel: str = ...
+    ) -> DescribeConnectorResponseTypeDef:
+        """
+        Describes the given custom connector registered in your Amazon Web Services
+        account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.describe_connector)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connector)
+        """
+
     def describe_connector_entity(
         self,
         *,
         connectorEntityName: str,
         connectorType: ConnectorTypeType = ...,
-        connectorProfileName: str = ...
+        connectorProfileName: str = ...,
+        apiVersion: str = ...
     ) -> DescribeConnectorEntityResponseTypeDef:
         """
         Provides details regarding the entity used with the connector, with a
         description of the data model for each entity.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.describe_connector_entity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.describe_connector_entity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connector_entity)
         """
 
@@ -158,6 +184,7 @@ class AppflowClient(BaseClient):
         *,
         connectorProfileNames: Sequence[str] = ...,
         connectorType: ConnectorTypeType = ...,
+        connectorLabel: str = ...,
         maxResults: int = ...,
         nextToken: str = ...
     ) -> DescribeConnectorProfilesResponseTypeDef:
@@ -165,17 +192,21 @@ class AppflowClient(BaseClient):
         Returns a list of `connector-profile` details matching the provided `connector-
         profile` names and `connector-types`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.describe_connector_profiles)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.describe_connector_profiles)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connector_profiles)
         """
 
     def describe_connectors(
-        self, *, connectorTypes: Sequence[ConnectorTypeType] = ..., nextToken: str = ...
+        self,
+        *,
+        connectorTypes: Sequence[ConnectorTypeType] = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> DescribeConnectorsResponseTypeDef:
         """
         Describes the connectors vended by Amazon AppFlow for specified connector types.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.describe_connectors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.describe_connectors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connectors)
         """
 
@@ -183,7 +214,7 @@ class AppflowClient(BaseClient):
         """
         Provides a description of the specified flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.describe_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.describe_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_flow)
         """
 
@@ -193,7 +224,7 @@ class AppflowClient(BaseClient):
         """
         Fetches the execution history of the flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.describe_flow_execution_records)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.describe_flow_execution_records)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_flow_execution_records)
         """
 
@@ -207,7 +238,7 @@ class AppflowClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#generate_presigned_url)
         """
 
@@ -216,22 +247,34 @@ class AppflowClient(BaseClient):
         *,
         connectorProfileName: str = ...,
         connectorType: ConnectorTypeType = ...,
-        entitiesPath: str = ...
+        entitiesPath: str = ...,
+        apiVersion: str = ...
     ) -> ListConnectorEntitiesResponseTypeDef:
         """
         Returns the list of available connector entities supported by Amazon AppFlow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.list_connector_entities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.list_connector_entities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_connector_entities)
         """
 
+    def list_connectors(
+        self, *, maxResults: int = ..., nextToken: str = ...
+    ) -> ListConnectorsResponseTypeDef:
+        """
+        Returns the list of all registered custom connectors in your Amazon Web Services
+        account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.list_connectors)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_connectors)
+        """
+
     def list_flows(
         self, *, maxResults: int = ..., nextToken: str = ...
     ) -> ListFlowsResponseTypeDef:
         """
         Lists all of the flows associated with your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.list_flows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.list_flows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_flows)
         """
 
@@ -239,15 +282,30 @@ class AppflowClient(BaseClient):
         """
         Retrieves the tags that are associated with a specified flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_tags_for_resource)
         """
 
+    def register_connector(
+        self,
+        *,
+        connectorLabel: str = ...,
+        description: str = ...,
+        connectorProvisioningType: Literal["LAMBDA"] = ...,
+        connectorProvisioningConfig: "ConnectorProvisioningConfigTypeDef" = ...
+    ) -> RegisterConnectorResponseTypeDef:
+        """
+        Registers a new connector with your Amazon Web Services account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.register_connector)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#register_connector)
+        """
+
     def start_flow(self, *, flowName: str) -> StartFlowResponseTypeDef:
         """
         Activates an existing flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.start_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.start_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#start_flow)
         """
 
@@ -255,7 +313,7 @@ class AppflowClient(BaseClient):
         """
         Deactivates the existing flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.stop_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.stop_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#stop_flow)
         """
 
@@ -263,15 +321,26 @@ class AppflowClient(BaseClient):
         """
         Applies a tag to the specified flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#tag_resource)
         """
 
+    def unregister_connector(
+        self, *, connectorLabel: str, forceDelete: bool = ...
+    ) -> Dict[str, Any]:
+        """
+        Unregisters the custom connector registered in your account that matches the
+        connectorLabel provided in the request.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.unregister_connector)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#unregister_connector)
+        """
+
     def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes a tag from the specified flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#untag_resource)
         """
 
@@ -285,7 +354,7 @@ class AppflowClient(BaseClient):
         """
         Updates a given connector profile associated with your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.update_connector_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.update_connector_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#update_connector_profile)
         """
 
@@ -302,6 +371,6 @@ class AppflowClient(BaseClient):
         """
         Updates an existing flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/appflow.html#Appflow.Client.update_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.update_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#update_flow)
         """
