@@ -22,7 +22,9 @@ else:
 __all__ = (
     "AggregationTypeType",
     "AmplitudeConnectorOperatorType",
+    "AuthenticationTypeType",
     "ConnectionModeType",
+    "ConnectorProvisioningTypeType",
     "ConnectorTypeType",
     "DataPullModeType",
     "DatadogConnectorOperatorType",
@@ -33,8 +35,10 @@ __all__ = (
     "GoogleAnalyticsConnectorOperatorType",
     "InforNexusConnectorOperatorType",
     "MarketoConnectorOperatorType",
+    "OAuth2GrantTypeType",
     "OperatorPropertiesKeysType",
     "OperatorType",
+    "OperatorsType",
     "PrefixFormatType",
     "PrefixTypeType",
     "PrivateConnectionProvisioningFailureCauseType",
@@ -59,9 +63,12 @@ __all__ = (
 
 AggregationTypeType = Literal["None", "SingleFile"]
 AmplitudeConnectorOperatorType = Literal["BETWEEN"]
+AuthenticationTypeType = Literal["APIKEY", "BASIC", "CUSTOM", "OAUTH2"]
 ConnectionModeType = Literal["Private", "Public"]
+ConnectorProvisioningTypeType = Literal["LAMBDA"]
 ConnectorTypeType = Literal[
     "Amplitude",
+    "CustomConnector",
     "CustomerProfiles",
     "Datadog",
     "Dynatrace",
@@ -158,6 +165,7 @@ MarketoConnectorOperatorType = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
+OAuth2GrantTypeType = Literal["AUTHORIZATION_CODE", "CLIENT_CREDENTIALS"]
 OperatorPropertiesKeysType = Literal[
     "CONCAT_FORMAT",
     "DATA_TYPE",
@@ -198,6 +206,29 @@ OperatorType = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
+OperatorsType = Literal[
+    "ADDITION",
+    "BETWEEN",
+    "CONTAINS",
+    "DIVISION",
+    "EQUAL_TO",
+    "GREATER_THAN",
+    "GREATER_THAN_OR_EQUAL_TO",
+    "LESS_THAN",
+    "LESS_THAN_OR_EQUAL_TO",
+    "MASK_ALL",
+    "MASK_FIRST_N",
+    "MASK_LAST_N",
+    "MULTIPLICATION",
+    "NOT_EQUAL_TO",
+    "NO_OP",
+    "PROJECTION",
+    "SUBTRACTION",
+    "VALIDATE_NON_NEGATIVE",
+    "VALIDATE_NON_NULL",
+    "VALIDATE_NON_ZERO",
+    "VALIDATE_NUMERIC",
+]
 PrefixFormatType = Literal["DAY", "HOUR", "MINUTE", "MONTH", "YEAR"]
 PrefixTypeType = Literal["FILENAME", "PATH", "PATH_AND_FILENAME"]
 PrivateConnectionProvisioningFailureCauseType = Literal[
@@ -377,7 +408,7 @@ VeevaConnectorOperatorType = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
-WriteOperationTypeType = Literal["INSERT", "UPDATE", "UPSERT"]
+WriteOperationTypeType = Literal["DELETE", "INSERT", "UPDATE", "UPSERT"]
 ZendeskConnectorOperatorType = Literal[
     "ADDITION",
     "DIVISION",
